\name{depth.contours}
\alias{distribution.depth.contours}
\alias{sample.depth.contours}
\alias{plot.depth.contours}
\title{Location-Scale Depth Contours}
\description{
  Calculates and plots location-scale depth contours based on Student depth
  for distributions (populations) and samples (data sets).
}

\usage{
   distribution.depth.contours(depth=c(0.1,0.2,0.3,0.4),qdist=function(x){qnorm(x,0,1)}, 
                   pdist=function(x){pnorm(x,0,1)},lengthmu=100,lengthbeta=100)  

  sample.depth.contours(depth=round(c(0.1,0.2,0.3,0.4)*length(y)),y,lengthmu=1000)

  plot.depth.contours(depth.cont,ratio=1,first.plot=T,mu.min=0,mu.max=0)
}

\arguments{
  \item{depth}{numerical vector of depth values in (0,0.5) for distributions,
                      integer vector of depth values within 1 and sample size for samples}
  \item{qdist}{quantile function of the distribution, default is the quantile function 
                     of the standard normal distribution.}
  \item{pdist}{distribution function of the distribution, default is the distribution function
                     of the standard normal distribution.}
  \item{y}{numerical vector of observations (data set)}
  \item{lengthmu}{length of the vector of location parameters for which upper and 
              lower bounds of the contour are calculated. The larger \code{lengthmu} is the 
                 smoother are the contour lines.}
 \item{lengthbeta}{length of the vector for calculating the upper and lower bound for the
                   contour for a given location parameter. The larger \code{lengthbeta} the more 
                      precise are the bounds.}
 \item{depth.cont}{a list given as output of  \code{distribution.depth.contours} or of
                             \code{sample.depth.contours}.}
 \item{ratio}{ratio of the lengths of the location and scale axes.}
 \item{first.plot}{if \code{first.plot=T} (default) a new plot is generated, if \code{first.plot=F} the plot 
           is added to an existing plot.}
\item{mu.min}{minimum value of the location axis. If \code{mu.min==mu.max} (default) 
         then the minimu and maximum value of the location axis is determined by the location 
         vector of the first list component of \code{depth.cont}.}
 \item{mu.max}{maximum value of the location axis. Compare \code{mu.min}.}
}
\details{
  \code{distribution.depth.contours} calculates the upper and lower bounds of
   the depth contours of a distribution (population).

  \code{sample.depth.contours} calculates the  the upper and lower bounds of
   the depth contours of a sample (data set).

  \code{plot.depth.contours} plots the contours given by 
     \code{distribution.depth.contours} or  \code{sample.depth.contours} .
}

\value{
  Return value of  \code{distribution.depth.contours}  and
     \code{sample.depth.contours} is a list. Each component of the list is list
     with the following components: \code{depth} provides the depth,
     \code{cont.exist} a logical value whether a contour for the depth exists. 
     If it is \code{TRUE} then the list has the further components:
     \code{mubound} a vector of location values, \code{lbound} a vector of the
     lower bounds of the scale values and \code{ubound} a vector of of the
     upper bounds of the scale values.

\code{plot.depth.contours} has no return value. 
}

\seealso{\code{\link{distribution.max.depth}}, \code{\link{sample.max.depth}}, 
            \code{\link{distribution.max.depth.line}},  \code{\link{sample.max.depth.line}}}

\examples{

 cauchy.depth.contours<-distribution.depth.contours(qdist=function(x){qt(x,1)},pdist=function(x){pt(x,1)}, lengthmu=1000)
 plot.depth.contours(cauchy.depth.contours)

 y<-rt(100,1)
 y.depth.contours<-sample.depth.contours(y=y,lengthmu=1000)
 plot.depth.contours(y.depth.contours)
 
}

\references{
 Mizera, I. and Mller, C.H. (2003). Location-scale depth.
 }

\author{
  Christine Mller (mueller@math.uni-oldenburg.de)
  }

\keyword{ Student depth }
\keyword{ depth contours }
\keyword{ location-scale }


\name{max.depth.line}
\alias{distribution.max.depth.line}
\alias{distribution.MAD.line}
\alias{distribution.MAD}
\alias{sample.max.depth.line}
\alias{sample.MAD.line}
\alias{add.max.depth.MAD.lines}

\title{Lines with maximum depth and MAD depending on the location}
\description{
  Calculates and plots 
  lines of scale parameters with maximum depth for  given location parameters
  and the lines of MAD with respect to given location parameters
  for distributions (populations)  and samples (data sets).
}

\usage{

distribution.max.depth.line(qdist=function(x){qnorm(x,0,1)}, pdist=function(x){pnorm(x,0,1)},mu.min,mu.max,
        lengthmu=50,d.min=0.05,lengthbeta=100,iter=50,eps=0.0001)

distribution.MAD(qdist=function(x){qnorm(x)}, pdist=function(x){pnorm(x)},mu=qdist(0.5),sym=F, 
       iter=100,eps=0.00000001)

distribution.MAD.line(qdist=function(x){qnorm(x)}, pdist=function(x){pnorm(x)},mu.min,mu.max,
       lengthmu=100,sym=F, iter=100,eps=0.00000001)

sample.max.depth.line(y,mu.min,mu.max,mu.values=T,lengthmu=100,iter=100,eps=0.0000001)

sample.MAD.line(y,mu.min,mu.max,mu.values=T,lengthmu=100)

add.max.depth.MAD.lines(max.depth.line=NULL,MAD.line=NULL)

 }

\arguments{
  \item{qdist}{quantile function of the distribution, default is the quantile function 
                     of the standard normal distribution.}
  \item{pdist}{distribution function of the distribution, default is the distribution function
                     of the standard normal distribution.}
  \item{mu}{location parameter from which the MAD is calculated, default is the median.}
  \item{y}{numerical vector of observations (data set)}
  \item{mu.min}{minimum value for the location parameters.}
  \item{mu.max}{maximum value for the location parameters.}
  \item{mu.values}{logical value where \code{mu.min} and \code{mu.max} are calculated
        from the data set if \code{mu.values=T} (default) otherwise the values must be set.}
  \item{lengthmu}{length of the vector of location parameters for which upper and 
              lower bounds of the contour are calculated. The larger \code{lengthmu} is the 
                 smoother the line is.}
  \item{d.min}{a value which is known to be smaller than the maximum depth for all used locations.} 
  \item{lengthbeta}{length of the vector for calculating the upper and lower bound for the
                   contour for a given location parameter and depth. The larger \code{lengthbeta} 
                   the more  precise are the bounds.}
  \item{iter}{number of iterations for each location parameter.}
  \item{eps}{precision of scale with maximum depth for a given location parameter.}
  \item{sym}{ if \code{sym=T}, then it is a symmetric distribution and mu is assumed to be the
           median.}
  \item{max.depth.line}{a list given by \code{distribution.max.depth.line} or 
          \code{sample.max.depth.line}. This list must have components \code{mu} and \code{s.mu} 
          where each components consist of a vector of same length. If \code{max.depth.line=NULL}, 
          (default) then the maximum depth line is not plotted.}
  \item{MAD.line}{a list given by \code{distribution.MAD.line} or 
          \code{sample.MAD.line}. This list must have components \code{mu} and \code{MAD} 
          where each components consist of a vector of same length. If \code{MAD=NULL}, 
          (default) then the maximum depth line is not plotted.}
}

\details{

  \code{distribution.max.depth.line} calculates scale parameters with maximum depth for
        several locations parameters for distributions.
 
 \code{distribution.MAD} calculates the median of absolute deviations from a given location 
        parameter for distributions.
 
  \code{distribution.MAD.line} calculates the median of absolute deviations from several location 
        parameters for distributions.
 
  \code{sample.max.depth.line} calculates scale parameters with maximum depth for
        several locations parameters for samples (data sets).
 
  \code{distribution.MAD.line} calculates the median of absolute deviations from several location 
        parameters for samples (data sets).
 
 The number of used locations parameters is given  by \code{lengthmu} and the location 
       parameters are lying equispaced in the interval from  \code{mu.min} to \code{mu.max}.

 \code{add.max.depth.MAD.lines} adds the lines given by \code{distribution.max.depth.line},
        \code{distribution.MAD.line}  or \code{sample.max.depth.line},  \code{distribution.MAD.line} 
        to an existing contour plot.
}

\value{
  Return value of  \code{distribution.max.depth.line}  and \code{sample.max.depth.line}  is
  a list with the following components:
       \code{mu} a vector of location parameters, 
       \code{s.mu} a vector with corresponding scale parameters with maximum depth.
  
  Return value of  \code{distribution.MAD.line}  and \code{sample.MAD.line}  is
  a list with the following components:
       \code{mu} a vector of location parameters, 
       \code{MAD} a vector with corresponding MAD's.

  \code{add.max.depth.MAD.lines} has no return value.
}

\seealso{\code{\link{distribution.depth.contours}}, \code{\link{sample.depth.contours}}, 
            \code{\link{distribution.max.depth}},  \code{\link{sample.max.depth}}}

\examples{

 normal.depth.contours<-distribution.depth.contours(lengthmu=1000)
 plot.depth.contours(normal.depth.contours)
 normal.max.depth.line<-distribution.max.depth.line(mu.min=-1.5,mu.max=1.5,lengthmu=100)
 normal.MAD.line<-distribution.MAD.line(mu.min=-1.5,mu.max=1.5,lengthmu=100)
 add.max.depth.MAD.lines(normal.max.depth.line)
 add.max.depth.MAD.lines(MAD.line=normal.MAD.line)

 y<-rt(100,1)
 y.depth.contours<-sample.depth.contours(y=y,lengthmu=1000)
 plot.depth.contours(y.depth.contours)
 y.max.depth.line<-sample.max.depth.line(y=y)
 y.MAD.line<-sample.MAD.line(y=y)
 add.max.depth.MAD.lines(y.max.depth.line,y.MAD.line)

 }

\references{
 Mizera, I. and Mller, C.H. (2003). Location-scale depth.
 }


\author{
  Christine Mller (mueller@math.uni-oldenburg.de)
  }


\keyword{ Student depth }
\keyword{ location-scale }
\keyword{ maximum depth for given location }
\keyword{ MAD }


\name{max.depth}
\alias{distribution.max.depth}
\alias{sample.max.depth}
\title{Maximum Depth}
\description{
  
  Calculates the maximum location-scale depth and 
  the location-scale parameter with maximum depth
  
}

\usage{

  distribution.max.depth(qdist=function(x){qnorm(x,0,1)}, pdist=function(x){pnorm(x,0,1)},
           d.min=1/3,lengthbeta=100,iter=10,eps=0.001)

  sample.max.depth(y,iter=100,eps=0.0001,p.length=10)

}

\arguments{

  \item{qdist}{quantile function of the distribution, default is the quantile function 
                     of the standard normal distribution.}
  \item{pdist}{distribution function of the distribution, default is the distribution function
                     of the standard normal distribution.}
  \item{y}{numerical vector of observations (data set)}
  \item{d.min}{a value which is known to be smaller than the maximum depth.}
  \item{lengthbeta}{length of the vector for calculating the upper and lower bound for the
                   contour for a given location parameter. The larger \code{lengthbeta} the more 
                      precise are the bounds.}
 \item{iter}{number of iterations.}
 \item{eps}{precision of location and scale with maximum depth.}
 \item{p.length}{maximum number of interations in a final precision step.}

}
\details{
  
  \code{distribution.max.depth} calculates the maximum depth and 
          the parameter pair of location and scale with maximum depth
          for a distribution (population).
  \code{sample.max.depth} calculates the maximum depth and the maximum
          depth estimator for location and scale for a sample (data set).  
 
}
\value{
  Both functions return a vector with the following components:
     \code{"max.depth"} is  the maximum depth, a value in (0,1) for distributions
            and an integer smaller than the sample size for samples
     \code{"mu"} is the location with maximum depth,
     \code{"sigma"} is the scale with maximum depth.
}


\seealso{\code{\link{distribution.depth.contours}}, \code{\link{sample.depth.contours}}, 
            \code{\link{distribution.max.depth.line}},  \code{\link{sample.max.depth.line}}}

\examples{
 
 distribution.max.depth(qdist=function(x){qt(x,1)},pdist=function(x){pt(x,1)},iter=50)

  y<-rt(100,1)
  sample.max.depth(y=y,iter=50)
  
}

\references{
   Mizera, I. and Mller, C.H. (2003). Location-scale depth.
}
\author{ Christine Mller, mueller@math.uni-oldenburg.de }


\keyword{ Student depth }
\keyword{ location-scale }
\keyword{ maximum depth }
\keyword{ maximum depth estimator }
